@@ -7,7 +7,7 @@ use Carp;
 use Data::Dumper;
 use Log::Log4perl qw(get_logger);
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 sub new {
 	my ( $class, $fw ) = @_;
@@ -27,43 +27,20 @@ sub new {
 
 	my $logger = get_logger(__PACKAGE__);
 	$logger->info("$self NEW");
-	$logger->info( "$self CONFIG ", $self->{CONFIG} );
+	$logger->info("$self CONFIG ",$self->{CONFIG});
 
-	$self->_make_index();
+	$self->_init();
 
 	return $self;
 }
 
-sub config {
-	return $_[0]->{CONFIG};
-}
+sub config { return $_[0]->{CONFIG}; }
+sub _index { return $_[0]->{INDEX}; }
 
-sub _make_index {
+sub _init {
 	my ($self) = @_;
-
-	my $logger = get_logger(__PACKAGE__);
-
-	foreach my $object ( $self->config()->iter() ) {
-		if (   $object->has_defined("ENTRY")
-			&& $object->has_defined("ID") )
-		{
-			if ( !$object->get("ID")->isa('Object::KVC::Hash') ) {
-				my $entry = $object->get("ENTRY")->as_string();
-				my $id    = $object->get("ID")->as_string();
-				if ( !defined $self->{INDEX}->{$entry}->{$id} ) {
-					$self->{INDEX}->{$entry}->{$id} = Object::KVC::Set->new();
-				}
-				my $set = $self->{INDEX}->{$entry}->{$id};
-				$set->add($object);
-			}
-		}
-		else {
-			# 'ENTRY' and 'ID' properties are required
-			$logger->error( "invalid object found ", Dumper($object) );
-		}
-	}
-
-	#print Dumper( $self->{INDEX} );
+	$self->{INDEX} = Object::KVC::Index->new( $self->config );
+	$self->{INDEX}->make_index( "ENTRY", "ID" );
 }
 
 sub _set_default_ports {
@@ -107,46 +84,7 @@ sub _set_default_ports {
 		}
 	}
 	else {
-		confess "_set_default_ports is for RULE objects only, not for ", Dumper($ce);
-	}
-}
-
-# Given an ::ObjectRef, return the set of actual objects.
-# The actual objects may contain references.
-sub _get_actual {
-	my ( $self, $ce ) = @_;
-
-	my $logger = get_logger(__PACKAGE__);
-	$logger->debug( "get_actual for : ", $ce->dump() );
-
-	if ( defined $self->{INDEX} ) {
-
-		my $entry = $ce->get("ENTRY")->as_string()
-		  or confess "'ENTRY' not found for ", $ce->dump();
-
-		my $id = $ce->get("ID")->as_string()
-		  or confess "'ID' not found for ", $ce->dump();
-
-		my $result = $self->{INDEX}->{$entry}->{$id};
-
-		$logger->debug( "actual set : $result : ", $result->as_string() );
-
-		return $result;
-	}
-	else {
-		my $result = Object::KVC::Set->new();
-
-		$self->config()->matches( $ce, $result );
-
-		if ( $result->size() == 0 ) {
-			$logger->error( "$self Error failed to find 
-			  actual configuration entry for\n", $ce->dump() );
-			return undef;
-		}
-
-		$logger->debug( "actual set : $result : ", $result->as_string() );
-
-		return $result;    #->first();
+		confess "_set_default_ports is for RULE objects only";
 	}
 }
 
@@ -163,16 +101,15 @@ sub expand_all {
 
 	my $rules = Object::KVC::List->new();
 
-	$self->config()->matches( $RULE_SEARCH, $rules );
+	$self->config->matches( $RULE_SEARCH, $rules );
 
 	foreach my $ce ( $rules->iter() ) {
 		eval {
-			#$logger->debug( "expanding ", $ce->get("ID")->as_string() );
 			my $clone = $ce->clone();
 			$self->_expand( $clone, $expanded );
 		};
 		if ($@) {
-			confess "$@ \n expand failed for ", $ce->dump(), "\n";
+			confess "$@ \n expand failed for ", Dumper($ce), "\n";
 		}
 	}
 
@@ -185,7 +122,7 @@ sub expand_all {
 # { 'key' => ::Set } is a list of config ::Hash or ::HashRef's.
 #   For every object in the Set clone the RULE object
 #   and replace the RULE value with the object from the ::Set
-# { 'key' => Object::KVC::Hash or Farly::IPv4 or Farly::Transport }
+# { 'key' => Object::KVC::Hash }
 #   use "OBJECT" key/value in the raw RULE object
 
 sub _expand {
@@ -205,10 +142,6 @@ sub _expand {
 	my $VIP = Object::KVC::Hash->new();
 	$VIP->set( "OBJECT_TYPE", Object::KVC::String->new("VIP") );
 
-	#my $TCPUDP = Object::KVC::Hash->new();
-	#$TCPUDP->set( "ENTRY", Object::KVC::String->new("GROUP") );
-	#$TCPUDP->set( "GROUP_PROTOCOL", Object::KVC::String->new("tcp-udp") );
-
 	while (@stack) {
 		my $ce = pop @stack;
 
@@ -221,19 +154,26 @@ sub _expand {
 			$is_expanded = 1;
 
 			if ( $value->isa("Object::KVC::HashRef") ) {
+
 				$is_expanded = 0;
 
-				my $actual = $self->_get_actual($value);
+				my $actual = $self->_index->fetch(
+					$value->get('ENTRY')->as_string(),
+					$value->get('ID')->as_string()
+				);
 
-				last if ( !defined($actual) );
+				if ( !defined $actual ) {
+					confess "actual not found for $key";
+				}
 
-				#print "key $key actual $actual\n";
 				$ce->set( $key, $actual );
 
 				push @stack, $ce;
+				
 				last;
 			}
 			elsif ( $value->isa("Object::KVC::Set") ) {
+
 				$is_expanded = 0;
 
 				$logger->debug("$ce => $key isa $value");
@@ -246,6 +186,7 @@ sub _expand {
 
 					push @stack, $clone;
 				}
+				
 				last;
 			}
 			elsif ( $value->isa("Object::KVC::Hash") ) {
@@ -254,10 +195,10 @@ sub _expand {
 
 				my $clone = $ce->clone();
 
-				#GROUP_PROTOCOL "tcp-udp"?
-
 				if ( $value->matches($COMMENT) ) {
-					$logger->debug( "skipped group comment :\n", $ce->dump(), "\n" );
+					
+					$logger->debug( "skipped group comment :\n", $ce->dump(),"\n" );
+
 					last;
 				}
 				if ( $value->matches($VIP) ) {
@@ -265,19 +206,22 @@ sub _expand {
 					$self->_expand_vip( $key, $clone, $value );
 				}
 				elsif ( $value->matches($SERVICE) ) {
+					
 					$self->_expand_service( $clone, $value );
 				}
 				elsif ( $value->has_defined("OBJECT") ) {
+					
 					$clone->set( $key, $value->get("OBJECT") );
 				}
 				else {
-					$logger->warn( "object $value :\n", $value->dump(), "has no OBJECT\n" );
-					$logger->warn( "skipped $ce :\n", $ce->dump(), "\n" );
+					
+					$logger->warn("skipped $ce property $key has no OBJECT\n", $ce->dump() );
+
 					last;
 				}
 
-				#print $clone->dump(),"\n";
 				push @stack, $clone;
+
 				last;
 			}
 		}
@@ -286,11 +230,8 @@ sub _expand {
 			$self->_set_default_ports($ce);
 			$result->add($ce);
 		}
-
-		#print "stack ",scalar(@stack)," result ",$result->size(),"\n";
 	}
 
-	#print "returning ",$result->size()," expanded rules\n";
 	return $result;
 }
 
@@ -309,7 +250,7 @@ sub _expand_vip {
 	my ( $self, $key, $clone, $vip_object ) = @_;
 
 	my $logger = get_logger(__PACKAGE__);
-	$logger->debug("processing VIP, $vip_object - key : $key");
+	$logger->debug("processing VIP : $vip_object - key : $key");
 
 	if ( $key eq "DST_IP" ) {
 		$clone->set( $key, $vip_object->get("REAL_IP") );
@@ -318,8 +259,8 @@ sub _expand_vip {
 		$clone->set( $key, $vip_object->get("REAL_PORT") );
 	}
 	else {
-		confess "invalid key for VIP\n", "key $key \n", $clone->dump(), "\n",
-		  $vip_object->dump(), "\n";
+		confess "invalid key for VIP\n", "key $key \n",
+		  "rule: ", $clone->dump(), "\n", "vip: ", $vip_object->dump(), "\n";
 	}
 
 	return;
@@ -344,7 +285,7 @@ firewall rule is for specific packet to firewall rule matching.
 
 =head1 METHODS
 
-=head2 new()
+=head2 new( $list )
 
 The constructor. The firewall configuration is provided.
 
@@ -373,4 +314,4 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with this program.  If not, see <http://www.gnu.org/licenses/>.
\ No newline at end of file
+along with this program.  If not, see <http://www.gnu.org/licenses/>.
